# Copyright 2020 Frank Bryden

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
Contains utility class `TestEntry`
"""

class TestEntry:
    """
    Models a single entry (row) in the resulting xlsx file.

    Contains all the relevant information about a single test:
        id:             Test ID
        name:           Test Name
        result:         PASS/FAIL
        error_message:  In case of FAIL, contains reason
        robot_file:     Robot file containing the test
    """
    def __init__(self, test_id, name, status, test_info):
        self.test_id = test_id
        self.name = name
        self.result = status[0]
        self.error_message = status[1]
        self.api = test_info[0]
        self.robot_file = test_info[1]

    def __str__(self):
        base_str = "[{}] {}:{}".format(self.test_id, self.name, self.result)
        if self.error_message != "":
            return "{}: {} ({}/{})".format(base_str, self.error_message, self.api, self.robot_file)

        return base_str

    def __repr__(self):
        return "{}: {}".format(self.name, self.result)

    def as_list(self):
        """
        Construct a list-representation of the entry
        """
        return [self.test_id, self.name, self.result, self.error_message, self.api, self.robot_file]
